-------------------------------------------------------------------------
-- (C) COPYRIGHT International Business Machines Corp. 2000-2002
-- All Rights Reserved
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
--
-- NAME: mclaim_db.ddl
--
-- FUNCTION: Create sample databases 
-------------------------------------------------------------------------

-- mclaim_db.ddl
-- DDL file for creating tables and populating data for Mobile Claim application on server side


FORCE APPLICATIONS ALL;
CONNECT RESET;
DISCONNECT MCLAIM;
DISCONNECT M_MC;

DB2STOP FORCE;
DB2START;




DROP DATABASE MCLAIM;

-- SQL statement to CREATE DATABASE
-- database name "MCLAIM" can translated
-- if translated it should correspond to the sample database name in other ddl files 

CREATE DATABASE MCLAIM;

-- SQL statement to increase heap size

UPDATE DB CONFIG FOR mclaim USING APPLHEAPSZ 2048;
UPDATE DB CONFIG FOR mclaim USING LOGFILSIZ 1000;

-- SQL statement to CONNECT to database "mclaim"
 
CONNECT TO MCLAIM;

-- SQL statement to create sample schema
-- New change
 
CREATE SCHEMA DSYSAMPLE;

-- Table Spaces



------------------------------------------------
-- Table "DSYSAMPLE"."ADJUSTER"
------------------------------------------------
 
 CREATE TABLE "DSYSAMPLE"."ADJUSTER"  (
		  "ADJUSTER_ID" INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY (  
		    START WITH +1  
		    INCREMENT BY +1  
		    MINVALUE +1  
		    MAXVALUE +2147483647  
		    NO CYCLE  
		    CACHE 20  
		    NO ORDER ) , 
		  "NAME" VARCHAR(40) , 
		  "TEL" VARCHAR(20) , 
		  "ADDRESS" VARCHAR(60) )   
		 IN "USERSPACE1" ; 
COMMENT ON TABLE "DSYSAMPLE"."ADJUSTER" IS 'information about adjuster';


-- P_KEY_1 "DSYSAMPLE"."ADJUSTER"

ALTER TABLE "DSYSAMPLE"."ADJUSTER" 
	ADD CONSTRAINT "P_KEY_1" PRIMARY KEY
		("ADJUSTER_ID");





------------------------------------------------
-- Table "DSYSAMPLE"."CLAIM"
------------------------------------------------
 
 CREATE TABLE "DSYSAMPLE"."CLAIM"  (
		  "CLAIM_ID" INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY (  
		    START WITH +1  
		    INCREMENT BY +1  
		    MINVALUE +1  
		    MAXVALUE +2147483647  
		    NO CYCLE  
		    CACHE 20  
		    NO ORDER ) , 
		  "POLICY_ID" INTEGER , 
		  "REPORTER_NAME" CHAR(40) , 
		  "REPORTER_ID" CHAR(30) , 
		  "REPORTER_REL" SMALLINT , 
		  "REPORTER_ADDR" VARCHAR(60) , 
		  "REPORTER_TEL" VARCHAR(20) , 
		  "CLAIM_PAY" DECIMAL(10,2) , 
		  "CLAIM_PAYTYPE" SMALLINT , 
		  "ACC_TIME" DATE , 
		  "ACC_LOCATION" VARCHAR(60) , 
		  "ACC_CAUSE" VARCHAR(200) , 
		  "ACC_DAMAGE" VARCHAR(200) , 
		  "ACC_RESPON" SMALLINT , 
		  "REPORT_OTHER" VARCHAR(60) , 
		  "ADJUSTER_ID" INTEGER , 
		  "STATUS" SMALLINT , 
		  "PRIOR" SMALLINT,
		  "COMMENTS" VARCHAR(200) )   
		 IN "USERSPACE1" ; 
COMMENT ON TABLE "DSYSAMPLE"."CLAIM" IS 'claim table';

COMMENT ON COLUMN "DSYSAMPLE"."CLAIM"."ACC_CAUSE" IS 'cause of accident';

COMMENT ON COLUMN "DSYSAMPLE"."CLAIM"."ACC_RESPON" IS 'responsibility of the accident

0: all; 1: main; 2: equal; 3: sub; 4: no';

COMMENT ON COLUMN "DSYSAMPLE"."CLAIM"."ACC_TIME" IS 'when accident happened';

COMMENT ON COLUMN "DSYSAMPLE"."CLAIM"."CLAIM_PAY" IS 'requested amount of money';

COMMENT ON COLUMN "DSYSAMPLE"."CLAIM"."CLAIM_PAYTYPE" IS 'way to get payment

0: cash; 1: check; 2: transfer; 3: other';

COMMENT ON COLUMN "DSYSAMPLE"."CLAIM"."PRIOR" IS 'priority of the claim, 0: low; 1: middle; 2: high;';

COMMENT ON COLUMN "DSYSAMPLE"."CLAIM"."REPORT_OTHER" IS 'name of other department handle the case';

COMMENT ON COLUMN "DSYSAMPLE"."CLAIM"."REPORTER_ID" IS 'requester ID card number';

COMMENT ON COLUMN "DSYSAMPLE"."CLAIM"."REPORTER_NAME" IS 'requester who raise the claim';

COMMENT ON COLUMN "DSYSAMPLE"."CLAIM"."REPORTER_REL" IS 'relationship between requester and insured

0: self; 1: guardian; 2: other';

COMMENT ON COLUMN "DSYSAMPLE"."CLAIM"."STATUS" IS '0: canceled; 1: wait; 2: processing; 3: confirm; 4: finished;';


-- Primary Key "DSYSAMPLE"."CLAIM"

ALTER TABLE "DSYSAMPLE"."CLAIM" 
	ADD PRIMARY KEY
		("CLAIM_ID");



------------------------------------------------
-- Table "DSYSAMPLE"."ITEM"
------------------------------------------------
 
 CREATE TABLE "DSYSAMPLE"."ITEM"  (
		  "POLICY_ITEM_ID" INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY (  
		    START WITH +1  
		    INCREMENT BY +1  
		    MINVALUE +1  
		    MAXVALUE +2147483647  
		    NO CYCLE  
		    CACHE 20  
		    NO ORDER ) , 
		  "POLICY_ID" INTEGER , 
		  "ITEM_NAME" CHAR(40) , 
		  "ITEM_QUOTA" DECIMAL(10,2) )   
		 IN "USERSPACE1" ; 
COMMENT ON TABLE "DSYSAMPLE"."ITEM" IS 'detail policy item according to the policy_item_id';

COMMENT ON COLUMN "DSYSAMPLE"."ITEM"."ITEM_NAME" IS 'name of policy type ';

COMMENT ON COLUMN "DSYSAMPLE"."ITEM"."ITEM_QUOTA" IS 'payment limitation of the item';

COMMENT ON COLUMN "DSYSAMPLE"."ITEM"."POLICY_ITEM_ID" IS 'relate to policy_item_id in dsy_policy table';


-- Primary Key "DSYSAMPLE"."ITEM"

ALTER TABLE "DSYSAMPLE"."ITEM" 
	ADD PRIMARY KEY
		("POLICY_ITEM_ID");



------------------------------------------------
-- Table "DSYSAMPLE"."LOSS"
------------------------------------------------
 
 CREATE TABLE "DSYSAMPLE"."LOSS"  (
		  "LOSS_ID" INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY (  
		    START WITH +1  
		    INCREMENT BY +1  
		    MINVALUE +1  
		    MAXVALUE +2147483647  
		    NO CYCLE  
		    CACHE 20  
		    NO ORDER ) , 
		  "CLAIM_ID" INTEGER , 
		  "EST_TIME" DATE , 
		  "EST_LOCATION" VARCHAR(60) , 
		  "EST_PARTDEG" VARCHAR(200) , 
		  "ITEM_CHANGED" INTEGER WITH DEFAULT 0 , 
		  "ITEM_COST" DECIMAL(10,2) , 
		  "REPAIR_COST" DECIMAL(10,2) , 
		  "REPAIR_START" DATE , 
		  "REPAIR_END" DATE , 
		  "SIGNATURE" BLOB(1048576) LOGGED NOT COMPACT  )   
		 IN "USERSPACE1" ; 
COMMENT ON TABLE "DSYSAMPLE"."LOSS" IS 'loss confirmation

this table need to be signed manually';

COMMENT ON COLUMN "DSYSAMPLE"."LOSS"."CLAIM_ID" IS 'relate to claim_id in dsy_claim';

COMMENT ON COLUMN "DSYSAMPLE"."LOSS"."EST_LOCATION" IS 'location of loss estimation';

COMMENT ON COLUMN "DSYSAMPLE"."LOSS"."EST_PARTDEG" IS 'summarization of demaged parts and related degree';

COMMENT ON COLUMN "DSYSAMPLE"."LOSS"."EST_TIME" IS 'time of loss estimate';

COMMENT ON COLUMN "DSYSAMPLE"."LOSS"."ITEM_COST" IS 'sum of all items cost';

COMMENT ON COLUMN "DSYSAMPLE"."LOSS"."REPAIR_COST" IS 'sum of repair cost';

COMMENT ON COLUMN "DSYSAMPLE"."LOSS"."REPAIR_END" IS 'finishing time of repair';

COMMENT ON COLUMN "DSYSAMPLE"."LOSS"."REPAIR_START" IS 'starting time of repairing';


-- Primary Key "DSYSAMPLE"."LOSS"

ALTER TABLE "DSYSAMPLE"."LOSS" 
	ADD PRIMARY KEY
		("LOSS_ID");



------------------------------------------------
-- Table "DSYSAMPLE"."MPOLICY"
------------------------------------------------
 
 CREATE TABLE "DSYSAMPLE"."MPOLICY"  (
		  "POLICY_ID" INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY (  
		    START WITH +1  
		    INCREMENT BY +1  
		    MINVALUE +1  
		    MAXVALUE +2147483647  
		    NO CYCLE  
		    CACHE 20  
		    NO ORDER ) , 
		  "POLICY_START" DATE , 
		  "POLICY_END" DATE , 
		  "HOLDER_NAME" CHAR(40) , 
		  "INSURED_NAME" CHAR(40) , 
		  "INSURED_ID" CHAR(30) , 
		  "INSURED_TEL" VARCHAR(20) , 
		  "VEHICLE_REL" SMALLINT , 
		  "DRIVER_NAME" CHAR(40) , 
		  "DRIVER_LICENCE" CHAR(30) , 
		  "VEHICLE_ID" CHAR(20) , 
		  "VEHICLE_MANU" VARCHAR(20) , 
		  "VEHICLE_MODEL" VARCHAR(20) , 
		  "VEHICLE_VIN" VARCHAR(17) , 
		  "VEHICLE_ENGID" VARCHAR(20) , 
		  "VEHICLE_COLOR" SMALLINT , 
		  "VEHICLE_SAFE" VARCHAR(20) , 
		  "VEHICLE_REGDATE" DATE , 
		  "VEHICLE_PAYN" SMALLINT , 
		  "VEHICLE_VIOLATE" SMALLINT )   
		 IN "USERSPACE1" ; 
COMMENT ON TABLE "DSYSAMPLE"."MPOLICY" IS 'policy table';

COMMENT ON COLUMN "DSYSAMPLE"."MPOLICY"."INSURED_ID" IS 'personal identity or corporation code of the insured';

COMMENT ON COLUMN "DSYSAMPLE"."MPOLICY"."VEHICLE_COLOR" IS '0: black; 1: white; 2: red; 3: gray; 4: blue; 5: yellow; 6: green; 7: purple; 8: pink; 9: brown; 10: other';

COMMENT ON COLUMN "DSYSAMPLE"."MPOLICY"."VEHICLE_ENGID" IS 'engine id of vehicle';

COMMENT ON COLUMN "DSYSAMPLE"."MPOLICY"."VEHICLE_ID" IS 'card number';

COMMENT ON COLUMN "DSYSAMPLE"."MPOLICY"."VEHICLE_MANU" IS 'manufacture type according to the factory';

COMMENT ON COLUMN "DSYSAMPLE"."MPOLICY"."VEHICLE_MODEL" IS 'specific model of related manufacture';

COMMENT ON COLUMN "DSYSAMPLE"."MPOLICY"."VEHICLE_PAYN" IS 'payment number related to loss of last year';

COMMENT ON COLUMN "DSYSAMPLE"."MPOLICY"."VEHICLE_REL" IS 'relation between insured and vehicle 0: own; 1: use; 2: manage';

COMMENT ON COLUMN "DSYSAMPLE"."MPOLICY"."VEHICLE_SAFE" IS 'safety facilities: 0: guard against theft; 1: ABS; 2: air cell';

COMMENT ON COLUMN "DSYSAMPLE"."MPOLICY"."VEHICLE_VIN" IS 'vehicle ID number';

COMMENT ON COLUMN "DSYSAMPLE"."MPOLICY"."VEHICLE_VIOLATE" IS 'peccancy number of last year';


-- Primary Key "DSYSAMPLE"."MPOLICY"

ALTER TABLE "DSYSAMPLE"."MPOLICY" 
	ADD PRIMARY KEY
		("POLICY_ID");



------------------------------------------------
-- Table "DSYSAMPLE"."PIC"
------------------------------------------------
 
 CREATE TABLE "DSYSAMPLE"."PIC"  (
		  "PIC_ID" VARCHAR(20) NOT NULL , 
		  "LOSS_ID" INTEGER , 
		  "PICTURE" BLOB(1048576) LOGGED NOT COMPACT )   
		 IN "USERSPACE1" ; 
COMMENT ON TABLE "DSYSAMPLE"."PIC" IS 'media information';

COMMENT ON COLUMN "DSYSAMPLE"."PIC"."LOSS_ID" IS 'relate to dsy_loss';

COMMENT ON COLUMN "DSYSAMPLE"."PIC"."PIC_ID" IS 'relate to media_id in dsy_loss';


-- Primary Key "DSYSAMPLE"."PIC"

ALTER TABLE "DSYSAMPLE"."PIC" 
	ADD PRIMARY KEY
		("PIC_ID");



------------------------------------------------
-- Table "DSYSAMPLE"."QUOTATION"
------------------------------------------------
 
 CREATE TABLE "DSYSAMPLE"."QUOTATION"  (
		  "QUOT_ID" INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY (  
		    START WITH 1  
		    INCREMENT BY +1  
		    MINVALUE +1  
		    MAXVALUE +2147483647  
		    NO CYCLE  
		    CACHE 20  
		    NO ORDER ) , 
		  "VEHICLE_MANU" VARCHAR(20) , 
		  "VEHICLE_MODEL" VARCHAR(20) , 
		  "PART_NAME" VARCHAR(40) , 
		  "PART_COST" DECIMAL(8,2) )   
		 IN "USERSPACE1" ; 
COMMENT ON TABLE "DSYSAMPLE"."QUOTATION" IS 'quotation of the parts need repairing';

COMMENT ON COLUMN "DSYSAMPLE"."QUOTATION"."PART_NAME" IS 'part name';

COMMENT ON COLUMN "DSYSAMPLE"."QUOTATION"."VEHICLE_MANU" IS 'manufacture of the vehicle';


-- Primary Key "DSYSAMPLE"."QUOTATION"

ALTER TABLE "DSYSAMPLE"."QUOTATION" 
	ADD PRIMARY KEY
		("QUOT_ID");



------------------------------------------------
-- Table "DSYSAMPLE"."RECORD"
------------------------------------------------
 
 CREATE TABLE "DSYSAMPLE"."RECORD"  (
		  "RECORD_ID" VARCHAR(20) NOT NULL, 
		  "LOSS_ID" INTEGER , 
		  "RECORD" BLOB(1048576) LOGGED NOT COMPACT )   
		 IN "USERSPACE1" ; 
COMMENT ON TABLE "DSYSAMPLE"."RECORD" IS 'media information';

COMMENT ON COLUMN "DSYSAMPLE"."RECORD"."LOSS_ID" IS 'relate to dsy_loss';

COMMENT ON COLUMN "DSYSAMPLE"."RECORD"."RECORD_ID" IS 'relate to media_id in dsy_loss';


-- Primary Key "DSYSAMPLE"."RECORD"

ALTER TABLE "DSYSAMPLE"."RECORD" 
	ADD PRIMARY KEY
		("RECORD_ID");



------------------------------------------------
-- Table "DSYSAMPLE"."REPAIRLIST"
------------------------------------------------
 
 CREATE TABLE "DSYSAMPLE"."REPAIRLIST"  (
		  "REPAIR_ID" INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY (  
		    START WITH +1  
		    INCREMENT BY +1  
		    MINVALUE +1  
		    MAXVALUE +2147483647  
		    NO CYCLE  
		    CACHE 20  
		    NO ORDER ) , 
		  "LOSS_ID" INTEGER NOT NULL, 
		  "REPAIR_NAME" VARCHAR(40) , 
		  "REPAIR_TIME" INTEGER , 
		  "REPAIR_COST_T" DECIMAL(8,2) , 
		  "REPAIR_COST_M" DECIMAL(8,2) , 
		  "COMMENT" VARCHAR(100) )   
		 IN "USERSPACE1" ; 
		 
COMMENT ON TABLE "DSYSAMPLE"."REPAIRLIST" IS 'cost information';
		 
COMMENT ON COLUMN "DSYSAMPLE"."REPAIRLIST"."REPAIR_COST_M" IS 'cost of material';

COMMENT ON COLUMN "DSYSAMPLE"."REPAIRLIST"."REPAIR_COST_T" IS 'cost according to the time';

COMMENT ON COLUMN "DSYSAMPLE"."REPAIRLIST"."REPAIR_NAME" IS 'name of repaired item';

COMMENT ON COLUMN "DSYSAMPLE"."REPAIRLIST"."REPAIR_TIME" IS 'time of repairing the item';


-- Primary Key "DSYSAMPLE"."REPAIRLIST"

ALTER TABLE "DSYSAMPLE"."REPAIRLIST" 
	ADD PRIMARY KEY
		("REPAIR_ID","LOSS_ID");




----------------------------

-- View: COUNTCASE

----------------------------
SET CURRENT SCHEMA = "DSYSAMPLE";
SET CURRENT PATH = "SYSIBM","SYSFUN","SYSPROC","DSYSAMPLE";
--create view countcase as  select adjuster_id, count(*) as cnt from claim
--group by adjuster_id, status having status <> 4;
create view countcase  as  select adjuster_id, count(*) as cnt from claim where status<>4
group by adjuster_id;




COMMENT ON TABLE "DSYSAMPLE"."COUNTCASE" IS 'count total cases processing by one adjuster';



-- Foreign Key "DSYSAMPLE"."CLAIM"

ALTER TABLE "DSYSAMPLE"."CLAIM" 
	ADD CONSTRAINT "F_REF1" FOREIGN KEY
		("POLICY_ID")
	REFERENCES "DSYSAMPLE"."MPOLICY"
		("POLICY_ID")
	ON DELETE CASCADE
	ON UPDATE RESTRICT
	ENFORCED
	ENABLE QUERY OPTIMIZATION;

ALTER TABLE "DSYSAMPLE"."CLAIM" 
	ADD CONSTRAINT "F_REF8" FOREIGN KEY
		("ADJUSTER_ID")
	REFERENCES "DSYSAMPLE"."ADJUSTER"
		("ADJUSTER_ID")
	ON DELETE CASCADE
	ON UPDATE RESTRICT
	ENFORCED
	ENABLE QUERY OPTIMIZATION;

-- Foreign Key "DSYSAMPLE"."ITEM"

ALTER TABLE "DSYSAMPLE"."ITEM" 
	ADD CONSTRAINT "F_REF2" FOREIGN KEY
		("POLICY_ID")
	REFERENCES "DSYSAMPLE"."MPOLICY"
		("POLICY_ID")
	ON DELETE CASCADE
	ON UPDATE RESTRICT
	ENFORCED
	ENABLE QUERY OPTIMIZATION;

-- Foreign Key "DSYSAMPLE"."LOSS"

ALTER TABLE "DSYSAMPLE"."LOSS" 
	ADD CONSTRAINT "F_REF3" FOREIGN KEY
		("CLAIM_ID")
	REFERENCES "DSYSAMPLE"."CLAIM"
		("CLAIM_ID")
	ON DELETE CASCADE
	ON UPDATE RESTRICT
	ENFORCED
	ENABLE QUERY OPTIMIZATION;

-- Foreign Key "DSYSAMPLE"."PIC"

ALTER TABLE "DSYSAMPLE"."PIC" 
	ADD CONSTRAINT "F_REF5" FOREIGN KEY
		("LOSS_ID")
	REFERENCES "DSYSAMPLE"."LOSS"
		("LOSS_ID")
	ON DELETE CASCADE
	ON UPDATE RESTRICT
	ENFORCED
	ENABLE QUERY OPTIMIZATION;

-- Foreign Key "DSYSAMPLE"."RECORD"

ALTER TABLE "DSYSAMPLE"."RECORD" 
	ADD CONSTRAINT "F_REF6" FOREIGN KEY
		("LOSS_ID")
	REFERENCES "DSYSAMPLE"."LOSS"
		("LOSS_ID")
	ON DELETE CASCADE
	ON UPDATE RESTRICT
	ENFORCED
	ENABLE QUERY OPTIMIZATION;

-- Foreign Key "DSYSAMPLE"."REPAIRLIST"

ALTER TABLE "DSYSAMPLE"."REPAIRLIST" 
	ADD CONSTRAINT "F_REF4" FOREIGN KEY
		("LOSS_ID")
	REFERENCES "DSYSAMPLE"."LOSS"
		("LOSS_ID")
	ON DELETE CASCADE
	ON UPDATE RESTRICT
	ENFORCED
	ENABLE QUERY OPTIMIZATION;


------------------------------------------------
-- Sample Data in Table "DSYSAMPLE"."ADJUSTER"
------------------------------------------------
 
INSERT INTO "DSYSAMPLE"."ADJUSTER" (NAME, TEL, ADDRESS) VALUES ('Adjuster1',	'+861033898273',	'No.7, East Road, Shang Di, Beijing');
INSERT INTO "DSYSAMPLE"."ADJUSTER" (NAME, TEL, ADDRESS) VALUES ('Adjuster2',	'+861023847219',	'No.108, South Road, Zhongguancun, Beijing');
INSERT INTO "DSYSAMPLE"."ADJUSTER" (NAME, TEL, ADDRESS) VALUES ('Adjuster3',	'+861037929743',	'No.88, North Street, Zhongguancun, Beijing');
INSERT INTO "DSYSAMPLE"."ADJUSTER" (NAME, TEL, ADDRESS) VALUES ('Adjuster4',	'+861089873723',	'No.18, West Road, Haidian Beijing');
INSERT INTO "DSYSAMPLE"."ADJUSTER" (NAME, TEL, ADDRESS) VALUES ('Adjuster5',	'+861067394729',	'No.77, Di An Men Street, Beijing');

------------------------------------------------
-- Sample Data in Table "DSYSAMPLE"."MPOLICY"
------------------------------------------------

INSERT INTO "DSYSAMPLE"."MPOLICY" VALUES (1,	'2005-06-01',	'2010-06-01',	'John',		'Simon',	'310293193812122020',	'+861033898259',	0,	'Simon',		'130406198104100010',	'A90295',	'Beijing Hyundai',	'SONATA 2.0 GL M/T',		'LSJDC24B43D037578',	'DOHC',	0,	'ABS+SRS',	'2005-05-20',	0,	0);
INSERT INTO "DSYSAMPLE"."MPOLICY" VALUES (2,	'2005-12-01',	'2010-12-01',	'Rose',		'Jack',		'310293198010311015',	'+861077949905',	0,	'Jack',			'250328197205200230',	'B19907',	'Hainan Mazda',		'HMC7161B 5MT GX1.6',		'JBURK32A69F033260',	'HBRT',	1,	'4W-ABS+EBD',	'2003-11-20',	1,	1);
INSERT INTO "DSYSAMPLE"."MPOLICY" VALUES (3,	'2006-07-01',	'2011-07-01',	'Jone',		'Tom',		'310293197723846058',	'+861094827988',	1,	'Tom',			'237293048282103043',	'C77799',	'Shanghai VW',		'Polo 1.4L AT',			'PKSTR67D23D927374',	'UKLB',	2,	'ABS+EBD',	'2006-05-20',	0,	0);

------------------------------------------------
-- Sample Data in Table "DSYSAMPLE"."CLAIM"
------------------------------------------------

INSERT INTO "DSYSAMPLE"."CLAIM" (POLICY_ID, REPORTER_NAME, REPORTER_ID, REPORTER_REL, REPORTER_ADDR, REPORTER_TEL, CLAIM_PAY, CLAIM_PAYTYPE, ACC_TIME, ACC_LOCATION, ACC_CAUSE, ACC_DAMAGE, ACC_RESPON, REPORT_OTHER, ADJUSTER_ID, STATUS, PRIOR) 
			 	VALUES (1,	'Simon',	'310293193812122020',	0,	'No.27, East Road, Shang Di, Beijing',	'+861033898259',	3200.00,		0,	'2007-05-05',	'East Road, Shang Di, Beijing',			'Drunk',	'headlight broken',			1,	'Police Office',	1,	3,	0);

INSERT INTO "DSYSAMPLE"."CLAIM" (POLICY_ID, REPORTER_NAME, REPORTER_ID, REPORTER_REL, REPORTER_ADDR, REPORTER_TEL, CLAIM_PAY, CLAIM_PAYTYPE, ACC_TIME, ACC_LOCATION, ACC_CAUSE, ACC_DAMAGE, ACC_RESPON, REPORT_OTHER, ADJUSTER_ID, STATUS, PRIOR) 
			 	VALUES (2,	'Jack',		'293873929281828373',	1,	'No.383, East Road, Shang Di, Beijing',	'+861032874613',	0.00,	1,	'2007-09-07',	'East Road, Shang Di, Beijing',			'self-ignite',	'whole',				0,	'No',			1,	1,	2);

INSERT INTO "DSYSAMPLE"."CLAIM" (POLICY_ID, REPORTER_NAME, REPORTER_ID, REPORTER_REL, REPORTER_ADDR, REPORTER_TEL, CLAIM_PAY, CLAIM_PAYTYPE, ACC_TIME, ACC_LOCATION, ACC_CAUSE, ACC_DAMAGE, ACC_RESPON, REPORT_OTHER, ADJUSTER_ID, STATUS, PRIOR) 
				VALUES (3,	'Tom',		'329193279862836483',	1,	'South Road, Zhongguancun, Beijing',	'+861067283619',	0.00,		0,	'2007-09-07',	'South Road, Zhongguancun, Beijing',		'Crash',	'headlight broken, bumper broken',	2,	'Police Office',	2,	1,	1);

INSERT INTO "DSYSAMPLE"."CLAIM" (POLICY_ID, REPORTER_NAME, REPORTER_ID, REPORTER_REL, REPORTER_ADDR, REPORTER_TEL, CLAIM_PAY, CLAIM_PAYTYPE, ACC_TIME, ACC_LOCATION, ACC_CAUSE, ACC_DAMAGE, ACC_RESPON, REPORT_OTHER, ADJUSTER_ID, STATUS, PRIOR) 
				VALUES (1,	'Simon',	'310293193812122020',	0,	'No.27, East Road, Shang Di, Beijing',	'+861033898259',	0.00,		0,	'2007-09-03',	'East Road, Shang Di, Beijing',			'Drunk',	'headlight broken',			1,	'Police Office',	3,	2,	1);



INSERT INTO "DSYSAMPLE"."CLAIM" (POLICY_ID, REPORTER_NAME, REPORTER_ID, REPORTER_REL, REPORTER_ADDR, REPORTER_TEL, CLAIM_PAY, CLAIM_PAYTYPE, ACC_TIME, ACC_LOCATION, ACC_CAUSE, ACC_DAMAGE, ACC_RESPON, REPORT_OTHER, ADJUSTER_ID, STATUS, PRIOR) 
			 	VALUES (2,	'Jack',		'293873929281828373',	1,	'No.383, East Road, Shang Di, Beijing',	'+861032874613',	0.00,	1,	'2007-09-07',	'East Road, Shang Di, Beijing',			'self-ignite',	'whole',				0,	'No',			4,	1,	2);

INSERT INTO "DSYSAMPLE"."CLAIM" (POLICY_ID, REPORTER_NAME, REPORTER_ID, REPORTER_REL, REPORTER_ADDR, REPORTER_TEL, CLAIM_PAY, CLAIM_PAYTYPE, ACC_TIME, ACC_LOCATION, ACC_CAUSE, ACC_DAMAGE, ACC_RESPON, REPORT_OTHER, ADJUSTER_ID, STATUS, PRIOR) 
				VALUES (3,	'Tom',		'329193279862836483',	1,	'South Road, Zhongguancun, Beijing',	'+861067283619',	0.00,		0,	'2007-09-07',	'South Road, Zhongguancun, Beijing',		'Crash',	'headlight broken, bumper broken',	2,	'Police Office',	5,	1,	2);


------------------------------------------------
-- Sample Data in Table "DSYSAMPLE"."ITEM"
------------------------------------------------

INSERT INTO "DSYSAMPLE"."ITEM" (POLICY_ID, ITEM_NAME, ITEM_QUOTA) VALUES (1,	'Vehicle loss',		140000.00);
INSERT INTO "DSYSAMPLE"."ITEM" (POLICY_ID, ITEM_NAME, ITEM_QUOTA) VALUES (1,	'Third Party',		2000.00);
INSERT INTO "DSYSAMPLE"."ITEM" (POLICY_ID, ITEM_NAME, ITEM_QUOTA) VALUES (1,	'Self-ignite',		100000.00);
INSERT INTO "DSYSAMPLE"."ITEM" (POLICY_ID, ITEM_NAME, ITEM_QUOTA) VALUES (1,	'Cargo',		20000.00);
INSERT INTO "DSYSAMPLE"."ITEM" (POLICY_ID, ITEM_NAME, ITEM_QUOTA) VALUES (2,	'Vehicle loss',		100000.00);
INSERT INTO "DSYSAMPLE"."ITEM" (POLICY_ID, ITEM_NAME, ITEM_QUOTA) VALUES (2,	'Third Party',		3000.00);
INSERT INTO "DSYSAMPLE"."ITEM" (POLICY_ID, ITEM_NAME, ITEM_QUOTA) VALUES (2,	'Self-ignite',		100000.00);
INSERT INTO "DSYSAMPLE"."ITEM" (POLICY_ID, ITEM_NAME, ITEM_QUOTA) VALUES (2,	'Person',		200000.00);
INSERT INTO "DSYSAMPLE"."ITEM" (POLICY_ID, ITEM_NAME, ITEM_QUOTA) VALUES (3,	'Vehicle loss',		90000.00);
INSERT INTO "DSYSAMPLE"."ITEM" (POLICY_ID, ITEM_NAME, ITEM_QUOTA) VALUES (3,	'Third Party',		2000.00);
INSERT INTO "DSYSAMPLE"."ITEM" (POLICY_ID, ITEM_NAME, ITEM_QUOTA) VALUES (3,	'Self-ignite',		100000.00);
INSERT INTO "DSYSAMPLE"."ITEM" (POLICY_ID, ITEM_NAME, ITEM_QUOTA) VALUES (3,	'Person',		200000.00);

------------------------------------------------
-- Sample Data in Table "DSYSAMPLE"."QUOTATION"
------------------------------------------------

INSERT INTO "DSYSAMPLE"."QUOTATION" (VEHICLE_MANU, VEHICLE_MODEL, PART_NAME, PART_COST)VALUES ('Beijing Hyundai',	'SONATA 2.0 GL M/T',		'Engine',		1500.00);
INSERT INTO "DSYSAMPLE"."QUOTATION" (VEHICLE_MANU, VEHICLE_MODEL, PART_NAME, PART_COST)VALUES ('Beijing Hyundai',	'SONATA 2.0 GL M/T',		'Window',		300.00);
INSERT INTO "DSYSAMPLE"."QUOTATION" (VEHICLE_MANU, VEHICLE_MODEL, PART_NAME, PART_COST)VALUES ('Beijing Hyundai',	'SONATA 2.0 GL M/T',		'Headlight',		100.00);
INSERT INTO "DSYSAMPLE"."QUOTATION" (VEHICLE_MANU, VEHICLE_MODEL, PART_NAME, PART_COST)VALUES ('Beijing Hyundai',	'SONATA 2.0 GL M/T',		'Bumper',		200.00);
INSERT INTO "DSYSAMPLE"."QUOTATION" (VEHICLE_MANU, VEHICLE_MODEL, PART_NAME, PART_COST)VALUES ('Beijing Hyundai',	'SONATA 2.0 GL M/T',		'Wheel',		500.00);
INSERT INTO "DSYSAMPLE"."QUOTATION" (VEHICLE_MANU, VEHICLE_MODEL, PART_NAME, PART_COST)VALUES ('Beijing Hyundai',	'SONATA 2.0 GL M/T',		'Door',			600.00);
INSERT INTO "DSYSAMPLE"."QUOTATION" (VEHICLE_MANU, VEHICLE_MODEL, PART_NAME, PART_COST)VALUES ('Beijing Hyundai',	'SONATA 2.0 GL M/T',		'Rearview mirror',	50.00);
INSERT INTO "DSYSAMPLE"."QUOTATION" (VEHICLE_MANU, VEHICLE_MODEL, PART_NAME, PART_COST)VALUES ('Hainan Mazda',		'HMC7161B 5MT GX1.6',		'Engine',		1500.00);
INSERT INTO "DSYSAMPLE"."QUOTATION" (VEHICLE_MANU, VEHICLE_MODEL, PART_NAME, PART_COST)VALUES ('Hainan Mazda',		'HMC7161B 5MT GX1.6',		'Window',		300.00);
INSERT INTO "DSYSAMPLE"."QUOTATION" (VEHICLE_MANU, VEHICLE_MODEL, PART_NAME, PART_COST)VALUES ('Hainan Mazda',		'HMC7161B 5MT GX1.6',		'Headlight',		100.00);
INSERT INTO "DSYSAMPLE"."QUOTATION" (VEHICLE_MANU, VEHICLE_MODEL, PART_NAME, PART_COST)VALUES ('Hainan Mazda',		'HMC7161B 5MT GX1.6',		'Bumper',		200.00);
INSERT INTO "DSYSAMPLE"."QUOTATION" (VEHICLE_MANU, VEHICLE_MODEL, PART_NAME, PART_COST)VALUES ('Hainan Mazda',		'HMC7161B 5MT GX1.6',		'Wheel',		500.00);
INSERT INTO "DSYSAMPLE"."QUOTATION" (VEHICLE_MANU, VEHICLE_MODEL, PART_NAME, PART_COST)VALUES ('Hainan Mazda',		'HMC7161B 5MT GX1.6',		'Door',			600.00);
INSERT INTO "DSYSAMPLE"."QUOTATION" (VEHICLE_MANU, VEHICLE_MODEL, PART_NAME, PART_COST)VALUES ('Hainan Mazda',		'HMC7161B 5MT GX1.6',		'Rearview Mirror',	50.00);
INSERT INTO "DSYSAMPLE"."QUOTATION" (VEHICLE_MANU, VEHICLE_MODEL, PART_NAME, PART_COST)VALUES ('Shanghai VW',		'Polo 1.4L AT',			'Engine',		1500.00);
INSERT INTO "DSYSAMPLE"."QUOTATION" (VEHICLE_MANU, VEHICLE_MODEL, PART_NAME, PART_COST)VALUES ('Shanghai VW',		'Polo 1.4L AT',			'Window',		300.00);
INSERT INTO "DSYSAMPLE"."QUOTATION" (VEHICLE_MANU, VEHICLE_MODEL, PART_NAME, PART_COST)VALUES ('Shanghai VW',		'Polo 1.4L AT',			'Headlight',		100.00);
INSERT INTO "DSYSAMPLE"."QUOTATION" (VEHICLE_MANU, VEHICLE_MODEL, PART_NAME, PART_COST)VALUES ('Shanghai VW',		'Polo 1.4L AT',			'Bumper',		200.00);
INSERT INTO "DSYSAMPLE"."QUOTATION" (VEHICLE_MANU, VEHICLE_MODEL, PART_NAME, PART_COST)VALUES ('Shanghai VW',		'Polo 1.4L AT',			'Wheel',		500.00);
INSERT INTO "DSYSAMPLE"."QUOTATION" (VEHICLE_MANU, VEHICLE_MODEL, PART_NAME, PART_COST)VALUES ('Shanghai VW',		'Polo 1.4L AT',			'Door',			600.00);
INSERT INTO "DSYSAMPLE"."QUOTATION" (VEHICLE_MANU, VEHICLE_MODEL, PART_NAME, PART_COST)VALUES ('Shanghai VW',		'Polo 1.4L AT',			'Rearview Mirror',	50.00);
------------------------------------------------
-- Sample Data in Table "DSYSAMPLE"."LOSS"
------------------------------------------------

INSERT INTO "DSYSAMPLE"."LOSS" (CLAIM_ID, EST_TIME, EST_LOCATION, EST_PARTDEG, ITEM_CHANGED, ITEM_COST, REPAIR_COST, REPAIR_START, REPAIR_END) VALUES (1,	'2006-06-06',	'No.68, East Road, Shang Di, Beijing',	'2 headlight damaged completely',	2,	600.00,	2600.00,	'2006-05-10',	'2006-06-01');
INSERT INTO "DSYSAMPLE"."LOSS" (CLAIM_ID) VALUES (2);
INSERT INTO "DSYSAMPLE"."LOSS" (CLAIM_ID) VALUES (3);
INSERT INTO "DSYSAMPLE"."LOSS" (CLAIM_ID) VALUES (4);
INSERT INTO "DSYSAMPLE"."LOSS" (CLAIM_ID) VALUES (5);
INSERT INTO "DSYSAMPLE"."LOSS" (CLAIM_ID) VALUES (6);

------------------------------------------------
-- Sample Data in Table "DSYSAMPLE"."REPAIRLIST"
------------------------------------------------

INSERT INTO "DSYSAMPLE"."REPAIRLIST" (REPAIR_ID,LOSS_ID, REPAIR_NAME, REPAIR_TIME, REPAIR_COST_T, REPAIR_COST_M, COMMENT) VALUES (1,1,	'123',	4,	75.00,	1900.00,	'1 2 3');
INSERT INTO "DSYSAMPLE"."REPAIRLIST" (REPAIR_ID,LOSS_ID, REPAIR_NAME, REPAIR_TIME, REPAIR_COST_T, REPAIR_COST_M, COMMENT) VALUES (2,1,	'45',	4,	75.00,	700.00,	'4 5');

------------------------------------------------
-- Sample Data in Table "DSYSAMPLE"."ITEM"
------------------------------------------------

--INSERT INTO "DSYSAMPLE"."PIC" (LOSS_ID, PICTURE) VALUES (1,	'');
--INSERT INTO "DSYSAMPLE"."PIC" (LOSS_ID, PICTURE) VALUES (1,	'');

------------------------------------------------
-- Sample Data in Table "DSYSAMPLE"."RECORDER"
------------------------------------------------

--INSERT INTO "DSYSAMPLE"."RECORDER" (LOSS_ID, RECORD) VALUES (1,	'');


COMMIT;

CONNECT RESET;

-- New for translation
-- SQL statement to create mirror database for jdbc subscription
-- "M_MC" can be translated

DROP DATABASE M_MC;

CREATE DATABASE M_MC;
UPDATE DB CONFIG FOR M_MC USING APPLHEAPSZ 2048;
UPDATE DB CONFIG FOR M_MC USING LOGFILSIZ 1000;

TERMINATE;
